#!/usr/bin/python
# coding: utf-8 -*-

# Copyright: (c) 2017, Dag Wieers <dag@wieers.com>
# GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r'''
---
module: win_tempfile
short_description: Creates temporary files and directories
description:
  - Creates temporary files and directories.
  - Since C(ansible.windows 3.6.0) this module can also run on non-Windows
    targets with PowerShell 7 present. Targeting non-Windows hosts requires
    Ansible C(2.22.0) or newer. Otherwise use the M(ansible.builtin.tempfile)
    module instead.
options:
  state:
    description:
      - Whether to create file or directory.
    type: str
    choices: [ directory, file ]
    default: file
  path:
    description:
      - Location where temporary file or directory should be created.
      - If path is not specified default temporary directory for the user will be used.
    type: path
    aliases: [ dest ]
  prefix:
    description:
      - Prefix of file/directory name created by module.
    type: str
    default: ansible.
  suffix:
    description:
      - Suffix of file/directory name created by module.
    type: str
seealso:
- module: ansible.builtin.tempfile
author:
- Dag Wieers (@dagwieers)
'''

EXAMPLES = r"""
- name: Create temporary build directory
  ansible.windows.win_tempfile:
    state: directory
    suffix: build

- name: Create temporary file with custom prefix
  ansible.windows.win_tempfile:
    state: file
    prefix: customlog_

- name: Create temporary file
  ansible.windows.win_tempfile:
    state: file
    suffix: temp
"""

RETURN = r'''
path:
  description: The absolute path to the created file or directory.
  returned: success
  type: str
  sample: C:\Users\Administrator\AppData\Local\Temp\ansible.bMlvdk
'''



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or
# https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
module: devices_camera_sense
short_description: Resource module for devices _camera _sense
description:
  - Manage operation update of the resource devices _camera _sense.
  - Update sense settings for the given camera.
version_added: '1.0.0'
extends_documentation_fragment:
  - cisco.meraki.module
author: Francisco Munoz (@fmunoz)
options:
  audioDetection:
    description: The details of the audio detection config.
    suboptions:
      enabled:
        description: Boolean indicating if audio detection is enabled(true) or disabled(false)
          on the camera.
        type: bool
    type: dict
  detectionModelId:
    description: The ID of the object detection model.
    type: str
  mqttBrokerId:
    description: The ID of the MQTT broker to be enabled on the camera. A value of
      null will disable MQTT on the camera.
    type: str
  senseEnabled:
    description: Boolean indicating if sense(license) is enabled(true) or disabled(false)
      on the camera.
    type: bool
  serial:
    description: Serial path parameter.
    type: str
requirements:
  - meraki >= 2.4.9
  - python >= 3.5
seealso:
  - name: Cisco Meraki documentation for camera updateDeviceCameraSense
    description: Complete reference of the updateDeviceCameraSense API.
    link: https://developer.cisco.com/meraki/api-v1/#!update-device-camera-sense
notes:
  - SDK Method used are
    camera.Camera.update_device_camera_sense,
  - Paths used are
    put /devices/{serial}/camera/sense,
"""

EXAMPLES = r"""
- name: Update all
  cisco.meraki.devices_camera_sense:
    meraki_api_key: "{{ meraki_api_key }}"
    meraki_base_url: "{{ meraki_base_url }}"
    meraki_single_request_timeout: "{{ meraki_single_request_timeout }}"
    meraki_certificate_path: "{{ meraki_certificate_path }}"
    meraki_requests_proxy: "{{ meraki_requests_proxy }}"
    meraki_wait_on_rate_limit: "{{ meraki_wait_on_rate_limit }}"
    meraki_nginx_429_retry_wait_time: "{{ meraki_nginx_429_retry_wait_time }}"
    meraki_action_batch_retry_wait_time: "{{ meraki_action_batch_retry_wait_time }}"
    meraki_retry_4xx_error: "{{ meraki_retry_4xx_error }}"
    meraki_retry_4xx_error_wait_time: "{{ meraki_retry_4xx_error_wait_time }}"
    meraki_maximum_retries: "{{ meraki_maximum_retries }}"
    meraki_output_log: "{{ meraki_output_log }}"
    meraki_log_file_prefix: "{{ meraki_log_file_prefix }}"
    meraki_log_path: "{{ meraki_log_path }}"
    meraki_print_console: "{{ meraki_print_console }}"
    meraki_suppress_logging: "{{ meraki_suppress_logging }}"
    meraki_simulate: "{{ meraki_simulate }}"
    meraki_be_geo_id: "{{ meraki_be_geo_id }}"
    meraki_caller: "{{ meraki_caller }}"
    meraki_use_iterator_for_get_pages: "{{ meraki_use_iterator_for_get_pages }}"
    meraki_inherit_logging_config: "{{ meraki_inherit_logging_config }}"
    state: present
    audioDetection:
      enabled: false
    detectionModelId: '1234'
    mqttBrokerId: '1234'
    senseEnabled: true
    serial: string
"""
RETURN = r"""
meraki_response:
  description: A dictionary or list with the response returned by the Cisco Meraki Python SDK
  returned: always
  type: dict
  sample: >
    {
      "senseEnabled": true,
      "mqttBrokerId": {},
      "mqttTopics": [
        "string"
      ],
      "audioDetection": {
        "enabled": true
      },
      "detectionModelId": {}
    }
"""



#!/usr/bin/python
#
# Copyright (c) 2024 xuzhang3 (@xuzhang3), Fred-sun (@Fred-sun)
#
# GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)

from __future__ import absolute_import, division, print_function
__metaclass__ = type


DOCUMENTATION = '''
---
module: azure_rm_mysqlflexiblefirewallrule
version_added: "2.7.0"
short_description: Manage MySQL flexible firewall rule instance
description:
    - Create, update and delete instance of MySQL flexible firewall rule.

options:
    resource_group:
        description:
            - The name of the resource group that contains the resource. You can obtain this value from the Azure Resource Manager API or the portal.
        required: True
        type: str
    server_name:
        description:
            - The name of the server.
        required: True
        type: str
    name:
        description:
            - The name of the MySQL flexible firewall rule.
        required: True
        type: str
    start_ip_address:
        description:
            - The start IP address of the MySQL flexible firewall rule. Must be IPv4 format.
            - Required when creating.
        type: str
    end_ip_address:
        description:
            - The end IP address of the MySQL flexible firewall rule. Must be IPv4 format.
            - Required when creating.
        type: str
    state:
        description:
            - Assert the state of the MySQL flexible firewall rule. Use C(present) to create or update a rule and C(absent) to ensure it is not present.
        default: present
        type: str
        choices:
            - absent
            - present

extends_documentation_fragment:
    - azure.azcollection.azure

author:
    - xuzhang3 (@xuzhang3)
    - Fred-sun (@Fred-sun)

'''

EXAMPLES = '''
- name: Create (or update) MySQL flexible firewall rule
  azure_rm_mysqlflexiblefirewallrule:
    resource_group: myResourceGroup
    server_name: testserver
    name: rule1
    start_ip_address: 10.0.0.17
    end_ip_address: 10.0.0.20

- name: Delete the MySQL flexible firewall rule
  azure_rm_mysqlflexiblefirewallrule:
    resource_group: myResourceGroup
    server_name: testserver
    name: rule1
    state: absent
'''

RETURN = '''
id:
    description:
        - Resource ID.
    returned: always
    type: str
    sample: "/subscriptions/xxxxxxxx/resourceGroups/myResourceGroup/providers/Microsoft.DBforMySQL/flexibleservers/testserver/firewallRules/rule1"
server_name:
    description:
        - The name of the server.
    returned: always
    type: str
    sample: testserver
name:
    description:
        - Resource name.
    returned: always
    type: str
    sample: rule1
start_ip_address:
    description:
        - The start IP address of the MySQL flexible firewall rule.
    returned: always
    type: str
    sample: 10.0.0.16
end_ip_address:
    description:
        - The end IP address of the MySQL flexible firewall rule.
    returned: always
    type: str
    sample: 10.0.0.18
'''

import time

try:
    from ansible_collections.azure.azcollection.plugins.module_utils.azure_rm_common import AzureRMModuleBase
    from azure.core.exceptions import ResourceNotFoundError
    from azure.core.polling import LROPoller
except ImportError:
    # This is handled in azure_rm_common
    pass


class Actions:
    NoAction, Create, Update, Delete = range(4)


class AzureRMMySqlFlexibleFirewallRule(AzureRMModuleBase):
    """Configuration class for an Azure RM MySQL flexible firewall rule resource"""

    def __init__(self):
        self.module_arg_spec = dict(
            resource_group=dict(
                type='str',
                required=True
            ),
            server_name=dict(
                type='str',
                required=True
            ),
            name=dict(
                type='str',
                required=True
            ),
            start_ip_address=dict(
                type='str'
            ),
            end_ip_address=dict(
                type='str'
            ),
            state=dict(
                type='str',
                default='present',
                choices=['present', 'absent']
            )
        )

        self.resource_group = None
        self.server_name = None
        self.name = None
        self.start_ip_address = None
        self.end_ip_address = None

        required_if = [('state', 'present', ['start_ip_address', 'end_ip_address'])]
        self.results = dict(changed=False)
        self.state = None
        self.parameters = dict()
        self.to_do = Actions.NoAction

        super(AzureRMMySqlFlexibleFirewallRule, self).__init__(derived_arg_spec=self.module_arg_spec,
                                                               supports_check_mode=True,
                                                               required_if=required_if,
                                                               supports_tags=False)

    def exec_module(self, **kwargs):
        """Main module execution method"""

        for key in list(self.module_arg_spec.keys()):
            if hasattr(self, key):
                setattr(self, key, kwargs[key])
                if key in ['start_ip_address', 'end_ip_address']:
                    self.parameters[key] = kwargs[key]

        old_response = None
        response = None

        old_response = self.get_firewallrule()

        if not old_response:
            self.log("MySQL flexible firewall rule instance doesn't exist")
            if self.state == 'absent':
                self.log("Old instance didn't exist")
            else:
                self.to_do = Actions.Create
        else:
            self.log("MySQL flexible firewall rule instance already exists")
            if self.state == 'absent':
                self.to_do = Actions.Delete
            elif self.state == 'present':
                self.log("Need to check if MySQL flexible firewall rule instance has to be deleted or may be updated")
                if (self.start_ip_address is not None) and (self.start_ip_address != old_response['start_ip_address']):
                    self.to_do = Actions.Update
                if (self.end_ip_address is not None) and (self.end_ip_address != old_response['end_ip_address']):
                    self.to_do = Actions.Update

        if (self.to_do == Actions.Create) or (self.to_do == Actions.Update):
            self.log("Need to Create / Update the MySQL flexible firewall rule instance")

            if self.check_mode:
                self.results['changed'] = True
                return self.results

            response = self.create_update_firewallrule()

            if not old_response:
                self.results['changed'] = True
            else:
                self.results['changed'] = old_response.__ne__(response)
            self.log("Creation / Update done")
        elif self.to_do == Actions.Delete:
            self.log("MySQL flexible firewall rule instance deleted")
            self.results['changed'] = True

            if self.check_mode:
                return self.results

            self.delete_firewallrule()
            # make sure instance is actually deleted, for some Azure resources, instance is hanging around
            # for some time after deletion -- this should be really fixed in Azure
            while self.get_firewallrule():
                time.sleep(20)
        else:
            self.log("MySQL flexible firewall rule instance unchanged")
            self.results['changed'] = False
            response = old_response

        if response:
            self.results["id"] = response["id"]
            self.results['name'] = self.name
            self.results['resource_group'] = self.resource_group
            self.results['server_name'] = self.server_name
            self.results['start_ip_address'] = response['start_ip_address']
            self.results['end_ip_address'] = response['end_ip_address']

        return self.results

    def create_update_firewallrule(self):
        '''
        Creates or updates MySQL flexible firewall rule with the specified configuration.

        :return: deserialized MySQL flexible firewall rule instance state dictionary
        '''
        self.log("Creating / Updating the MySQL flexible firewall rule instance {0}".format(self.name))

        try:
            response = self.mysql_flexible_client.firewall_rules.begin_create_or_update(resource_group_name=self.resource_group,
                                                                                        server_name=self.server_name,
                                                                                        firewall_rule_name=self.name,
                                                                                        parameters=self.parameters)
            if isinstance(response, LROPoller):
                response = self.get_poller_result(response)

        except Exception as exc:
            self.log('Error attempting to create the MySQL flexible firewall rule instance.')
            self.fail("Error creating the MySQL flexible firewall rule instance: {0}".format(str(exc)))
        return response.as_dict()

    def delete_firewallrule(self):
        '''
        Deletes specified MySQL flexible firewall rule instance in the specified subscription and resource group.

        :return: True
        '''
        self.log("Deleting the MySQL flexible firewall rule instance {0}".format(self.name))
        try:
            response = self.mysql_flexible_client.firewall_rules.begin_delete(resource_group_name=self.resource_group,
                                                                              server_name=self.server_name,
                                                                              firewall_rule_name=self.name)
        except Exception as e:
            self.log('Error attempting to delete the MySQL flexible firewall rule instance.')
            self.fail("Error deleting the MySQL flexible firewall rule instance: {0}".format(str(e)))

        return True

    def get_firewallrule(self):
        '''
        Gets the properties of the specified MySQL flexible firewall rule.

        :return: deserialized MySQL flexible firewall rule instance state dictionary
        '''
        self.log("Checking if the MySQL flexible firewall rule instance {0} is present".format(self.name))
        found = False
        try:
            response = self.mysql_flexible_client.firewall_rules.get(resource_group_name=self.resource_group,
                                                                     server_name=self.server_name,
                                                                     firewall_rule_name=self.name)
            found = True
            self.log("Response : {0}".format(response))
            self.log("MySQL flexible firewall rule instance : {0} found".format(response.name))
        except ResourceNotFoundError as e:
            self.log('Did not find the MySQL flexible firewall rule instance.')
        if found is True:
            return response.as_dict()

        return False


def main():
    """Main execution"""
    AzureRMMySqlFlexibleFirewallRule()


if __name__ == '__main__':
    main()



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or
# https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
module: organizations_appliance_uplinks_nat_by_network_info
short_description: Information module for organizations _appliance _uplinks _nat _by
  _network
description:
  - Get all organizations _appliance _uplinks _nat _by _network.
  - Fetch uplink NAT settings of each network in the organization.
version_added: '1.0.0'
extends_documentation_fragment:
  - cisco.meraki.module_info
  - cisco.meraki.module_info_pagination
author: Francisco Munoz (@fmunoz)
options:
  headers:
    description: Additional headers.
    type: dict
  organizationId:
    description:
      - OrganizationId path parameter. Organization ID.
    type: str
  networkIds:
    description:
      - NetworkIds query parameter. Optional parameter to filter the results by the
        included set of network IDs.
    elements: str
    type: list
  interfaces:
    description:
      - Interfaces query parameter. Optional parameter to filter the results by the
        included set of interfaces.
    elements: str
    type: list
  perPage:
    description:
      - PerPage query parameter. The number of entries per page returned. Acceptable
        range is 3 - 100000. Default is 1000.
    type: int
  startingAfter:
    description:
      - >
        StartingAfter query parameter. A token used by the server to indicate the
        start of the page. Often this is a timestamp or an ID but it is not limited
        to those. This parameter should not be defined by client applications. The
        link for the first, last, prev, or next page in the HTTP Link header should
        define it.
    type: str
  endingBefore:
    description:
      - >
        EndingBefore query parameter. A token used by the server to indicate the end
        of the page. Often this is a timestamp or an ID but it is not limited to those.
        This parameter should not be defined by client applications. The link for
        the first, last, prev, or next page in the HTTP Link header should define
        it.
    type: str
requirements:
  - meraki >= 2.4.9
  - python >= 3.5
seealso:
  - name: Cisco Meraki documentation for appliance getOrganizationApplianceUplinksNatByNetwork
    description: Complete reference of the getOrganizationApplianceUplinksNatByNetwork
      API.
    link: https://developer.cisco.com/meraki/api-v1/#!get-organization-appliance-uplinks-nat-by-network
notes:
  - SDK Method used are
    appliance.Appliance.get_organization_appliance_uplinks_nat_by_network,
  - Paths used are
    get /organizations/{organizationId}/appliance/uplinks/nat/byNetwork,
"""

EXAMPLES = r"""
- name: Get all organizations _appliance _uplinks _nat _by _network
  cisco.meraki.organizations_appliance_uplinks_nat_by_network_info:
    meraki_api_key: "{{ meraki_api_key }}"
    meraki_base_url: "{{ meraki_base_url }}"
    meraki_single_request_timeout: "{{ meraki_single_request_timeout }}"
    meraki_certificate_path: "{{ meraki_certificate_path }}"
    meraki_requests_proxy: "{{ meraki_requests_proxy }}"
    meraki_wait_on_rate_limit: "{{ meraki_wait_on_rate_limit }}"
    meraki_nginx_429_retry_wait_time: "{{ meraki_nginx_429_retry_wait_time }}"
    meraki_action_batch_retry_wait_time: "{{ meraki_action_batch_retry_wait_time }}"
    meraki_retry_4xx_error: "{{ meraki_retry_4xx_error }}"
    meraki_retry_4xx_error_wait_time: "{{ meraki_retry_4xx_error_wait_time }}"
    meraki_maximum_retries: "{{ meraki_maximum_retries }}"
    meraki_output_log: "{{ meraki_output_log }}"
    meraki_log_file_prefix: "{{ meraki_log_file_prefix }}"
    meraki_log_path: "{{ meraki_log_path }}"
    meraki_print_console: "{{ meraki_print_console }}"
    meraki_suppress_logging: "{{ meraki_suppress_logging }}"
    meraki_simulate: "{{ meraki_simulate }}"
    meraki_be_geo_id: "{{ meraki_be_geo_id }}"
    meraki_caller: "{{ meraki_caller }}"
    meraki_use_iterator_for_get_pages: "{{ meraki_use_iterator_for_get_pages }}"
    meraki_inherit_logging_config: "{{ meraki_inherit_logging_config }}"
    networkIds: []
    interfaces: []
    perPage: 0
    startingAfter: string
    endingBefore: string
    organizationId: string
    total_pages: -1
    direction: next
  register: result
"""
RETURN = r"""
meraki_response:
  description: A dictionary or list with the response returned by the Cisco Meraki Python SDK
  returned: always
  type: list
  elements: dict
  sample: >
    [
      {
        "networkId": "string",
        "uplinks": [
          {
            "interface": "string",
            "nat": {
              "enabled": true
            }
          }
        ]
      }
    ]
"""
